@@ -9,6 +9,7 @@ from copy import deepcopy
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
+from typing import ClassVar
 
 from packaging.utils import canonicalize_name
 
@@ -104,7 +105,7 @@ _default_config: Config | None = None
 
 
 class Config:
-    default_config: dict[str, Any] = {
+    default_config: ClassVar[dict[str, Any]] = {
         "cache-dir": str(DEFAULT_CACHE_DIR),
         "virtualenvs": {
             "create": True,
@@ -132,6 +133,9 @@ class Config:
             "max-workers": None,
             "no-binary": None,
         },
+        "warnings": {
+            "export": True,
+        },
     }
 
     def __init__(
@@ -222,6 +226,22 @@ class Config:
             path = Path(self.get("cache-dir")) / "virtualenvs"
         return Path(path).expanduser()
 
+    @property
+    def installer_max_workers(self) -> int:
+        # This should be directly handled by ThreadPoolExecutor
+        # however, on some systems the number of CPUs cannot be determined
+        # (it raises a NotImplementedError), so, in this case, we assume
+        # that the system only has one CPU.
+        try:
+            default_max_workers = (os.cpu_count() or 1) + 4
+        except NotImplementedError:
+            default_max_workers = 5
+
+        desired_max_workers = self.get("installer.max-workers")
+        if desired_max_workers is None:
+            return default_max_workers
+        return min(default_max_workers, int(desired_max_workers))
+
     def get(self, setting_name: str, default: Any = None) -> Any:
         """
         Retrieve a setting value.
@@ -278,6 +298,7 @@ class Config:
             "experimental.system-git-client",
             "installer.modern-installation",
             "installer.parallel",
+            "warnings.export",
         }:
             return boolean_normalizer
 
