@@ -20,18 +20,14 @@ class UpdateCommand(InstallerCommand):
         option(
             "no-dev",
             None,
-            (
-                "Do not update the development dependencies."
-                " (<warning>Deprecated</warning>)"
-            ),
+            "Do not update the development dependencies."
+            " (<warning>Deprecated</warning>)",
         ),
         option(
             "dry-run",
             None,
-            (
-                "Output the operations but do not execute anything "
-                "(implicitly enables --verbose)."
-            ),
+            "Output the operations but do not execute anything "
+            "(implicitly enables --verbose).",
         ),
         option("lock", None, "Do not perform operations (only update the lockfile)."),
     ]
