@@ -9,6 +9,7 @@ from hashlib import sha256
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
+from typing import ClassVar
 from typing import cast
 
 from packaging.utils import canonicalize_name
@@ -50,8 +51,13 @@ class Locker:
     _VERSION = "2.0"
     _READ_VERSION_RANGE = ">=1,<3"
 
-    _legacy_keys = ["dependencies", "source", "extras", "dev-dependencies"]
-    _relevant_keys = [*_legacy_keys, "group"]
+    _legacy_keys: ClassVar[list[str]] = [
+        "dependencies",
+        "source",
+        "extras",
+        "dev-dependencies",
+    ]
+    _relevant_keys: ClassVar[list[str]] = [*_legacy_keys, "group"]
 
     def __init__(self, lock: Path, local_config: dict[str, Any]) -> None:
         self._lock = lock
@@ -317,6 +323,14 @@ class Locker:
             except tomllib.TOMLDecodeError as e:
                 raise RuntimeError(f"Unable to read the lock file ({e}).")
 
+        # if the lockfile doesn't contain a metadata section at all,
+        # it probably needs to be rebuilt completely
+        if "metadata" not in lock_data:
+            raise RuntimeError(
+                "The lock file does not have a metadata entry.\n"
+                "Regenerate the lock file with the `poetry lock` command."
+            )
+
         metadata = lock_data["metadata"]
         lock_version = Version.parse(metadata.get("lock-version", "1.0"))
         current_version = Version.parse(self._VERSION)
@@ -430,10 +444,7 @@ class Locker:
             "description": package.description or "",
             "optional": package.optional,
             "python-versions": package.python_versions,
-            "files": sorted(
-                package.files,
-                key=lambda x: x["file"],  # type: ignore[no-any-return]
-            ),
+            "files": sorted(package.files, key=lambda x: x["file"]),
         }
 
         if dependencies:
