@@ -13,15 +13,20 @@ from typing import TYPE_CHECKING
 from typing import Any
 
 import requests
+import requests.adapters
 import requests.auth
 import requests.exceptions
 
-from cachecontrol import CacheControl
+from cachecontrol import CacheControlAdapter
 from cachecontrol.caches import FileCache
+from requests_toolbelt import user_agent
 
+from poetry.__version__ import __version__
 from poetry.config.config import Config
 from poetry.exceptions import PoetryException
 from poetry.utils.constants import REQUESTS_TIMEOUT
+from poetry.utils.constants import RETRY_AFTER_HEADER
+from poetry.utils.constants import STATUS_FORCELIST
 from poetry.utils.password_manager import HTTPAuthCredential
 from poetry.utils.password_manager import PasswordManager
 
@@ -106,15 +111,16 @@ class Authenticator:
         io: IO | None = None,
         cache_id: str | None = None,
         disable_cache: bool = False,
+        pool_size: int = requests.adapters.DEFAULT_POOLSIZE,
     ) -> None:
         self._config = config or Config.create()
         self._io = io
         self._sessions_for_netloc: dict[str, requests.Session] = {}
         self._credentials: dict[str, HTTPAuthCredential] = {}
         self._certs: dict[str, RepositoryCertificateConfig] = {}
-        self._configured_repositories: dict[
-            str, AuthenticatorRepositoryConfig
-        ] | None = None
+        self._configured_repositories: (
+            dict[str, AuthenticatorRepositoryConfig] | None
+        ) = None
         self._password_manager = PasswordManager(self._config)
         self._cache_control = (
             FileCache(
@@ -122,7 +128,7 @@ class Authenticator:
                     self._config.repository_cache_directory
                     / (cache_id or "_default_cache")
                     / "_http"
-                )
+                ),
             )
             if not disable_cache
             else None
@@ -130,14 +136,23 @@ class Authenticator:
         self.get_repository_config_for_url = functools.lru_cache(maxsize=None)(
             self._get_repository_config_for_url
         )
+        self._pool_size = pool_size
+        self._user_agent = user_agent("poetry", __version__)
 
     def create_session(self) -> requests.Session:
         session = requests.Session()
+        session.headers["User-Agent"] = self._user_agent
 
         if self._cache_control is None:
             return session
 
-        session = CacheControl(sess=session, cache=self._cache_control)
+        adapter = CacheControlAdapter(
+            cache=self._cache_control,
+            pool_maxsize=self._pool_size,
+        )
+        session.mount("http://", adapter)
+        session.mount("https://", adapter)
+
         return session
 
     def get_session(self, url: str | None = None) -> requests.Session:
@@ -219,6 +234,7 @@ class Authenticator:
         send_kwargs.update(settings)
 
         attempt = 0
+        resp = None
 
         while True:
             is_last_attempt = attempt >= 5
@@ -228,21 +244,29 @@ class Authenticator:
                 if is_last_attempt:
                     raise e
             else:
-                if resp.status_code not in [502, 503, 504] or is_last_attempt:
+                if resp.status_code not in STATUS_FORCELIST or is_last_attempt:
                     if raise_for_status:
                         resp.raise_for_status()
                     return resp
 
             if not is_last_attempt:
                 attempt += 1
-                delay = 0.5 * attempt
-                logger.debug(f"Retrying HTTP request in {delay} seconds.")
+                delay = self._get_backoff(resp, attempt)
+                logger.debug("Retrying HTTP request in %s seconds.", delay)
                 time.sleep(delay)
                 continue
 
         # this should never really be hit under any sane circumstance
         raise PoetryException("Failed HTTP {} request", method.upper())
 
+    def _get_backoff(self, response: requests.Response | None, attempt: int) -> float:
+        if response is not None:
+            retry_after = response.headers.get(RETRY_AFTER_HEADER, "")
+            if retry_after:
+                return float(retry_after)
+
+        return 0.5 * attempt
+
     def get(self, url: str, **kwargs: Any) -> requests.Response:
         return self.request("get", url, **kwargs)
 
@@ -355,9 +379,9 @@ class Authenticator:
             self._configured_repositories = {}
             for repository_name in self._config.get("repositories", []):
                 url = self._config.get(f"repositories.{repository_name}.url")
-                self._configured_repositories[
-                    repository_name
-                ] = AuthenticatorRepositoryConfig(repository_name, url)
+                self._configured_repositories[repository_name] = (
+                    AuthenticatorRepositoryConfig(repository_name, url)
+                )
 
         return self._configured_repositories
 
