@@ -47,8 +47,18 @@ class PoetryKeyring:
 
         import keyring
 
+        from keyring.errors import KeyringError
+        from keyring.errors import KeyringLocked
+
         for name in names:
-            credential = keyring.get_credential(name, username)
+            credential = None
+            try:
+                credential = keyring.get_credential(name, username)
+            except KeyringLocked:
+                logger.debug("Keyring %s is locked", name)
+            except (KeyringError, RuntimeError):
+                logger.debug("Accessing keyring %s failed", name, exc_info=True)
+
             if credential:
                 return HTTPAuthCredential(
                     username=credential.username, password=credential.password
@@ -109,8 +119,8 @@ class PoetryKeyring:
     def _check(self) -> None:
         try:
             import keyring
-        except Exception as e:
-            logger.debug(f"An error occurred while importing keyring: {e!s}")
+        except ImportError as e:
+            logger.debug("An error occurred while importing keyring: %s", e)
             self._is_available = False
 
             return
@@ -134,7 +144,7 @@ class PoetryKeyring:
                     and "plaintext" not in b.name.lower()
                     for b in backends
                 )
-            except Exception:
+            except ImportError:
                 self._is_available = False
 
         if not self._is_available:
@@ -193,16 +203,13 @@ class PasswordManager:
         self.keyring.delete_password(name, "__token__")
 
     def get_http_auth(self, name: str) -> dict[str, str | None] | None:
-        auth = self._config.get(f"http-basic.{name}")
-        if not auth:
-            username = self._config.get(f"http-basic.{name}.username")
-            password = self._config.get(f"http-basic.{name}.password")
-            if not username and not password:
-                return None
-        else:
-            username, password = auth["username"], auth.get("password")
-            if password is None:
-                password = self.keyring.get_password(name, username)
+        username = self._config.get(f"http-basic.{name}.username")
+        password = self._config.get(f"http-basic.{name}.password")
+        if not username and not password:
+            return None
+
+        if not password:
+            password = self.keyring.get_password(name, username)
 
         return {
             "username": username,
