@@ -22,21 +22,8 @@ class SystemGit:
 
     @classmethod
     def checkout(cls, rev: str, target: Path | None = None) -> str:
-        args = []
-
-        if target:
-            args += [
-                "--git-dir",
-                (target / ".git").as_posix(),
-                "--work-tree",
-                target.as_posix(),
-            ]
-
         cls._check_parameter(rev)
-
-        args += ["checkout", rev]
-
-        return cls.run(*args)
+        return cls.run("checkout", rev, folder=target)
 
     @staticmethod
     def run(*args: Any, **kwargs: Any) -> str:
@@ -53,15 +40,12 @@ class SystemGit:
         git_command = find_git_command()
         env = os.environ.copy()
         env["GIT_TERMINAL_PROMPT"] = "0"
-        return (
-            subprocess.check_output(
-                git_command + list(args),
-                stderr=subprocess.STDOUT,
-                env=env,
-            )
-            .decode()
-            .strip()
-        )
+        return subprocess.check_output(
+            git_command + list(args),
+            stderr=subprocess.STDOUT,
+            env=env,
+            text=True,
+        ).strip()
 
     @staticmethod
     def _check_parameter(parameter: str) -> None:
